# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/buyesrfolio/transactions/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/buyesrfolio/transactions/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Buyesrfolio\\Transactions\\": "packages/buyesrfolio/transactions/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Buyesrfolio\Transactions\Providers\TransactionsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Transactions'  => Buyesrfolio\Transactions\Facades\Transactions::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Buyesrfolio\\TransactionsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Buyesrfolio\Transactions\Providers\TransactionsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Buyesrfolio\Transactions\Providers\TransactionsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Buyesrfolio\Transactions\Providers\TransactionsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/transactions/{modulename}

**User**

    http://path-to-route-folder/user/transactions/{modulename}

**Public**

    http://path-to-route-folder/transactions


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/transactions/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/transactions/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/transactions/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/transactions/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/transactions/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/transactions/{modulename}/{slug}
    METHOD: GET