<?php

namespace Buyesrfolio\Transactions\Policies;

use Litepie\User\Contracts\UserPolicy;
use Buyesrfolio\Transactions\Models\PastTransaction;

class PastTransactionPolicy
{

    /**
     * Determine if the given user can view the past_transaction.
     *
     * @param UserPolicy $user
     * @param PastTransaction $past_transaction
     *
     * @return bool
     */
    public function view(UserPolicy $user, PastTransaction $past_transaction)
    {
        if ($user->canDo('transactions.past_transaction.view') && $user->isAdmin()) {
            return true;
        }

        return $past_transaction->user_id == user_id() && $past_transaction->user_type == user_type();
    }

    /**
     * Determine if the given user can create a past_transaction.
     *
     * @param UserPolicy $user
     * @param PastTransaction $past_transaction
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('transactions.past_transaction.create');
    }

    /**
     * Determine if the given user can update the given past_transaction.
     *
     * @param UserPolicy $user
     * @param PastTransaction $past_transaction
     *
     * @return bool
     */
    public function update(UserPolicy $user, PastTransaction $past_transaction)
    {
        if ($user->canDo('transactions.past_transaction.edit') && $user->isAdmin()) {
            return true;
        }

        return $past_transaction->user_id == user_id() && $past_transaction->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given past_transaction.
     *
     * @param UserPolicy $user
     * @param PastTransaction $past_transaction
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PastTransaction $past_transaction)
    {
        return $past_transaction->user_id == user_id() && $past_transaction->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given past_transaction.
     *
     * @param UserPolicy $user
     * @param PastTransaction $past_transaction
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PastTransaction $past_transaction)
    {
        if ($user->canDo('transactions.past_transaction.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given past_transaction.
     *
     * @param UserPolicy $user
     * @param PastTransaction $past_transaction
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PastTransaction $past_transaction)
    {
        if ($user->canDo('transactions.past_transaction.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
