<?php

namespace Buyesrfolio\Transactions\Providers;

use Illuminate\Support\ServiceProvider;

class TransactionsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'transactions');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'transactions');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerTransactions();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerTransactions()
    {
        $this->app->bind('transactions', function($app) {
            return new Transactions($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Transactions', 'Lavalite\Transactions\Facades\Transactions');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('buyesrfolio.transactions', function ($app) {
            return $this->app->make('Buyesrfolio\Transactions\Transactions');
        });

        // Bind PastTransaction to repository
        $this->app->bind(
            'Buyesrfolio\Transactions\Interfaces\PastTransactionRepositoryInterface',
            \Buyesrfolio\Transactions\Repositories\Eloquent\PastTransactionRepository::class
        );
        // Bind TransactionFile to repository
        $this->app->bind(
            'Buyesrfolio\Transactions\Interfaces\TransactionFileRepositoryInterface',
            \Buyesrfolio\Transactions\Repositories\Eloquent\TransactionFileRepository::class
        );

        $this->app->register(\Buyesrfolio\Transactions\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Buyesrfolio\Transactions\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and transactions's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'buyesrfolio.transactions'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeTransactions::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['buyesrfolio.transactions'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('buyesrfolio/transactions.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/transactions')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/transactions')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
